==> vue-sb-components-2.3.32.tgz: package/components/form-input-mask/form-input-mask.js <==
import "./form-input-mask.css";
import { defineComponent as k, resolveDirective as v, openBlock as r, createElementBlock as t, mergeProps as c, createElementVNode as o, normalizeClass as a, toDisplayString as f, createCommentVNode as i, withModifiers as b, renderSlot as M, withDirectives as I, vModelText as q, Fragment as m, createTextVNode as F } from "vue";
import { U as O } from "../../maska-e074d7a3.js";
import { _ as V } from "../../_plugin-vue_export-helper-dad06003.js";
const C = k({
  emits: {
    "update:modelValue": (e) => !0,
    blur: (e) => !0,
    focus: (e) => !0,
    input: (e) => !0,
    keydown: (e) => !0
  },
  props: {
    autocomplete: {
      default: "on",
      type: String
    },
    disabled: {
      required: !1,
      type: Boolean
    },
    errorMessage: {
      required: !1,
      type: [String, Function]
    },
    icon: {
      required: !1,
      type: Object
    },
    isError: {
      required: !1,
      type: Boolean
    },
    isFocus: {
      required: !1,
      type: Boolean
    },
    label: {
      required: !1,
      type: String
    },
    maskaOptions: {
      required: !1,
      type: Object
    },
    modelValue: {
      required: !1,
      type: null
    },
    pattern: {
      required: !1,
      type: String
    },
    placeholder: {
      required: !1,
      type: String
    },
    readOnly: {
      required: !1,
      type: Boolean
    },
    required: {
      required: !1,
      type: Boolean
    },
    tabindex: {
      required: !1,
      type: Number
    },
    textAlign: {
      default: "left",
      type: String
    },
    value: {
      required: !1,
      type: null
    },
    variant: {
      default: "default",
      required: !1,
      type: String
    }
  },
  name: "sb-form-input",
  directives: {
    maska: O
  },
  data() {
    return {
      localIsFocus: !1,
      localValue: this.modelValue || this.value || null
    };
  },
  computed: {
    getMaskaOptions() {
      return {
        ...this.pattern && {
          mask: this.pattern
        },
        ...this.maskaOptions && {
          ...this.maskaOptions
        }
      };
    },
    isFilled() {
      return this.localValue && (this.localValue !== "" || this.localValue.length);
    }
  },
  methods: {
    handleBlur(e) {
      this.localIsFocus = !1, this.$emit("blur", e);
    },
    handleChange(e) {
      this.$emit("input", e), this.$emit("update:modelValue", this.localValue);
    },
    handleClickIcon(e) {
      var l;
      return ((l = this.icon) == null ? void 0 : l.onClick) && this.icon.onClick(e);
    },
    handleClickOutsideInput(e) {
      const l = e.target, n = this.$refs["input-wrapper"];
      l && n && !n.contains(l) && !l.isSameNode(n) && this.toggleFocus(!1);
    },
    handleErrorMessage() {
      return this.errorMessage ? typeof this.errorMessage == "string" ? this.errorMessage : this.errorMessage(this.localValue) : "";
    },
    handleInputFocus(e) {
      this.localIsFocus = !0, this.$emit("focus", e);
    },
    handleMouseLeaveIcon(e) {
      var l;
      return ((l = this.icon) == null ? void 0 : l.onMouseLeave) && this.icon.onMouseLeave(e);
    },
    handleMouseOverIcon(e) {
      var l;
      return ((l = this.icon) == null ? void 0 : l.onMouseOver) && this.icon.onMouseOver(e);
    },
    toggleFocus(e, l) {
      if (l) {
        const n = l.target, u = n == null ? void 0 : n.querySelectorAll("input");
        u.length > 0 && u[0].focus();
      }
      this.localIsFocus = e;
    }
  },
  watch: {
    isFocus(e) {
      this.localIsFocus = e;
    },
    modelValue: {
      handler(e) {
        this.localValue = e;
      }
    },
    value: {
      handler(e) {
        this.localValue = e;
      }
    }
  },
  mounted() {
    document.addEventListener(
      "click",
      (e) => this.handleClickOutsideInput(e)
    );
  },
  unmounted() {
    document.removeEventListener(
      "click",
      (e) => this.handleClickOutsideInput(e)
    );
  }
});
const $ = {
  key: 0,
  class: "asterisk"
}, B = ["tabindex"], S = { class: "input-border" }, w = { class: "notch" }, E = {
  key: 0,
  class: "asterisk"
}, L = {
  key: 0,
  class: "error-wrapper"
}, N = ["innerHTML"];
function T(e, l, n, u, y, A) {
  var d, p, h;
  const g = v("maska");
  return r(), t("div", c({
    class: ["input-wrapper", { error: e.isError, flat: e.variant === "flat" }],
    ref: "input-wrapper"
  }, { ...e.$attrs }), [
    o("div", {
      class: a(["input-group", {
        disabled: e.disabled,
        filled: e.isFilled,
        focus: e.isFocus || e.localIsFocus,
        icon_append: ((d = e.icon) == null ? void 0 : d.placement) === "append",
        icon_prepend: ((p = e.icon) == null ? void 0 : p.placement) === "prepend",
        readonly: e.readOnly
      }])
    }, [
      e.label ? (r(), t("label", {
        key: 0,
        class: a(["label", { required: e.required }])
      }, [
        o("span", null, f(e.label), 1),
        e.required ? (r(), t("span", $, "*")) : i("", !0)
      ], 2)) : i("", !0),
      e.icon ? (r(), t("span", {
        key: 1,
        class: a([{
          "sb-cursor-pointer": (h = e.icon) == null ? void 0 : h.onClick
        }, "icon"]),
        onClick: l[0] || (l[0] = b((...s) => e.handleClickIcon && e.handleClickIcon(...s), ["stop"])),
        onMouseover: l[1] || (l[1] = (...s) => e.handleMouseOverIcon && e.handleMouseOverIcon(...s)),
        onMouseleave: l[2] || (l[2] = (...s) => e.handleMouseLeaveIcon && e.handleMouseLeaveIcon(...s))
      }, [
        M(e.$slots, "icon-slot")
      ], 34)) : i("", !0),
      o("div", {
        class: a(["form-control", ["text", e.textAlign]]),
        onClick: l[8] || (l[8] = (s) => e.toggleFocus(!0, s))
      }, [
        I(o("input", c({
          tabindex: e.readOnly || e.disabled ? -1 : e.tabindex,
          type: "text",
          "onUpdate:modelValue": l[3] || (l[3] = (s) => e.localValue = s)
        }, {
          autocomplete: e.autocomplete,
          disabled: e.disabled,
          placeholder: e.placeholder,
          readonly: e.readOnly
        }, {
          onBlur: l[4] || (l[4] = (s) => e.handleBlur(s)),
          onFocus: l[5] || (l[5] = (s) => e.handleInputFocus(s)),
          onInput: l[6] || (l[6] = (s) => e.handleChange(s)),
          onKeydown: l[7] || (l[7] = (s) => e.$emit("keydown", s))
        }), null, 16, B), [
          [g, void 0, e.getMaskaOptions],
          [q, e.localValue]
        ])
      ], 2),
      o("fieldset", S, [
        o("legend", w, [
          o("span", {
            class: a(["notch-label", { "no-label": !e.label || e.label === "" }])
          }, [
            e.label && e.label !== "" ? (r(), t(m, { key: 0 }, [
              o("span", null, f(e.label), 1),
              e.required ? (r(), t("span", E, "*")) : i("", !0)
            ], 64)) : (r(), t(m, { key: 1 }, [
              F("​")
            ], 64))
          ], 2)
        ])
      ])
    ], 2),
    e.isError && e.errorMessage ? (r(), t("div", L, [
      o("span", {
        innerHTML: e.handleErrorMessage()
      }, null, 8, N)
    ])) : i("", !0)
  ], 16);
}
const U = /* @__PURE__ */ V(C, [["render", T]]);
export {
  U as default
};

==> vue-sb-components-2.4.23.tgz: package/components/form-input-mask/form-input-mask.js <==
import "./form-input-mask.css";
import { defineComponent as k, resolveDirective as v, openBlock as r, createElementBlock as t, mergeProps as c, createElementVNode as o, normalizeClass as a, toDisplayString as f, createCommentVNode as i, withModifiers as b, renderSlot as M, withDirectives as I, vModelText as q, Fragment as m, createTextVNode as F } from "vue";
import { U as O } from "../../maska-e074d7a3.js";
import { _ as V } from "../../_plugin-vue_export-helper-dad06003.js";
const C = k({
  emits: {
    "update:modelValue": (e) => !0,
    blur: (e) => !0,
    focus: (e) => !0,
    input: (e) => !0,
    keydown: (e) => !0
  },
  props: {
    autocomplete: {
      required: !1,
      type: Boolean
    },
    disabled: {
      required: !1,
      type: Boolean
    },
    errorMessage: {
      required: !1,
      type: [String, Function]
    },
    icon: {
      required: !1,
      type: Object
    },
    isError: {
      required: !1,
      type: Boolean
    },
    isFocus: {
      required: !1,
      type: Boolean
    },
    label: {
      required: !1,
      type: String
    },
    maskaOptions: {
      required: !1,
      type: Object
    },
    modelValue: {
      required: !1,
      type: null
    },
    pattern: {
      required: !1,
      type: String
    },
    placeholder: {
      required: !1,
      type: String
    },
    readOnly: {
      required: !1,
      type: Boolean
    },
    required: {
      required: !1,
      type: Boolean
    },
    tabindex: {
      required: !1,
      type: Number
    },
    textAlign: {
      default: "left",
      type: String
    },
    value: {
      required: !1,
      type: null
    },
    variant: {
      default: "default",
      required: !1,
      type: String
    }
  },
  name: "sb-form-input",
  directives: {
    maska: O
  },
  data() {
    return {
      localIsFocus: !1,
      localValue: this.modelValue || this.value || null
    };
  },
  computed: {
    getMaskaOptions() {
      return {
        ...this.pattern && {
          mask: this.pattern
        },
        ...this.maskaOptions && {
          ...this.maskaOptions
        }
      };
    },
    isFilled() {
      return this.localValue && (this.localValue !== "" || this.localValue.length);
    }
  },
  methods: {
    handleBlur(e) {
      this.localIsFocus = !1, this.$emit("blur", e);
    },
    handleChange(e) {
      this.$emit("input", e), this.$emit("update:modelValue", this.localValue);
    },
    handleClickIcon(e) {
      var l;
      return ((l = this.icon) == null ? void 0 : l.onClick) && this.icon.onClick(e);
    },
    handleClickOutsideInput(e) {
      const l = e.target, n = this.$refs["input-wrapper"];
      l && n && !n.contains(l) && !l.isSameNode(n) && this.toggleFocus(!1);
    },
    handleErrorMessage() {
      return this.errorMessage ? typeof this.errorMessage == "string" ? this.errorMessage : this.errorMessage(this.localValue) : "";
    },
    handleInputFocus(e) {
      this.localIsFocus = !0, this.$emit("focus", e);
    },
    handleMouseLeaveIcon(e) {
      var l;
      return ((l = this.icon) == null ? void 0 : l.onMouseLeave) && this.icon.onMouseLeave(e);
    },
    handleMouseOverIcon(e) {
      var l;
      return ((l = this.icon) == null ? void 0 : l.onMouseOver) && this.icon.onMouseOver(e);
    },
    toggleFocus(e, l) {
      if (l) {
        const n = l.target, u = n == null ? void 0 : n.querySelectorAll("input");
        u.length > 0 && u[0].focus();
      }
      this.localIsFocus = e;
    }
  },
  watch: {
    isFocus(e) {
      this.localIsFocus = e;
    },
    modelValue: {
      handler(e) {
        this.localValue = e;
      }
    },
    value: {
      handler(e) {
        this.localValue = e;
      }
    }
  },
  mounted() {
    document.addEventListener(
      "click",
      (e) => this.handleClickOutsideInput(e)
    );
  },
  unmounted() {
    document.removeEventListener(
      "click",
      (e) => this.handleClickOutsideInput(e)
    );
  }
});
const B = {
  key: 0,
  class: "asterisk"
}, $ = ["autocomplete", "tabindex"], w = { class: "input-border" }, S = { class: "notch" }, E = {
  key: 0,
  class: "asterisk"
}, L = {
  key: 0,
  class: "error-wrapper"
}, N = ["innerHTML"];
function T(e, l, n, u, y, A) {
  var d, p, h;
  const g = v("maska");
  return r(), t("div", c({
    class: ["input-wrapper", { error: e.isError, flat: e.variant === "flat" }],
    ref: "input-wrapper"
  }, { ...e.$attrs }), [
    o("div", {
      class: a(["input-group", {
        disabled: e.disabled,
        filled: e.isFilled,
        focus: e.isFocus || e.localIsFocus,
        icon_append: ((d = e.icon) == null ? void 0 : d.placement) === "append",
        icon_prepend: ((p = e.icon) == null ? void 0 : p.placement) === "prepend",
        readonly: e.readOnly
      }])
    }, [
      e.label ? (r(), t("label", {
        key: 0,
        class: a(["label", { required: e.required }])
      }, [
        o("span", null, f(e.label), 1),
        e.required ? (r(), t("span", B, "*")) : i("", !0)
      ], 2)) : i("", !0),
      e.icon ? (r(), t("span", {
        key: 1,
        class: a([{
          "sb-cursor-pointer": (h = e.icon) == null ? void 0 : h.onClick
        }, "icon"]),
        onClick: l[0] || (l[0] = b((...s) => e.handleClickIcon && e.handleClickIcon(...s), ["stop"])),
        onMouseover: l[1] || (l[1] = (...s) => e.handleMouseOverIcon && e.handleMouseOverIcon(...s)),
        onMouseleave: l[2] || (l[2] = (...s) => e.handleMouseLeaveIcon && e.handleMouseLeaveIcon(...s))
      }, [
        M(e.$slots, "icon-slot")
      ], 34)) : i("", !0),
      o("div", {
        class: a(["form-control", ["text", e.textAlign]]),
        onClick: l[8] || (l[8] = (s) => e.toggleFocus(!0, s))
      }, [
        I(o("input", c({
          autocomplete: e.autocomplete ? "on" : "off",
          tabindex: e.readOnly || e.disabled ? -1 : e.tabindex,
          type: "text",
          "onUpdate:modelValue": l[3] || (l[3] = (s) => e.localValue = s)
        }, {
          disabled: e.disabled,
          placeholder: e.placeholder,
          readonly: e.readOnly
        }, {
          onBlur: l[4] || (l[4] = (s) => e.handleBlur(s)),
          onFocus: l[5] || (l[5] = (s) => e.handleInputFocus(s)),
          onInput: l[6] || (l[6] = (s) => e.handleChange(s)),
          onKeydown: l[7] || (l[7] = (s) => e.$emit("keydown", s))
        }), null, 16, $), [
          [g, void 0, e.getMaskaOptions],
          [q, e.localValue]
        ])
      ], 2),
      o("fieldset", w, [
        o("legend", S, [
          o("span", {
            class: a(["notch-label", { "no-label": !e.label || e.label === "" }])
          }, [
            e.label && e.label !== "" ? (r(), t(m, { key: 0 }, [
              o("span", null, f(e.label), 1),
              e.required ? (r(), t("span", E, "*")) : i("", !0)
            ], 64)) : (r(), t(m, { key: 1 }, [
              F("​")
            ], 64))
          ], 2)
        ])
      ])
    ], 2),
    e.isError && e.errorMessage ? (r(), t("div", L, [
      o("span", {
        innerHTML: e.handleErrorMessage()
      }, null, 8, N)
    ])) : i("", !0)
  ], 16);
}
const U = /* @__PURE__ */ V(C, [["render", T]]);
export {
  U as default
};
